==> huaweicloudsdksfsturbo-3.1.124-py2.py3-none-any.whl: huaweicloudsdksfsturbo/v1/model/delete_hpc_cache_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteHpcCacheTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'share_id': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'share_id': 'share_id',
        'task_id': 'task_id'
    }

    def __init__(self, share_id=None, task_id=None):
        """DeleteHpcCacheTaskRequest

        The model defined in huaweicloud sdk

        :param share_id: 文件系统ID
        :type share_id: str
        :param task_id: 任务ID
        :type task_id: str
        """
        
        

        self._share_id = None
        self._task_id = None
        self.discriminator = None

        self.share_id = share_id
        self.task_id = task_id

    @property
    def share_id(self):
        """Gets the share_id of this DeleteHpcCacheTaskRequest.

        文件系统ID

        :return: The share_id of this DeleteHpcCacheTaskRequest.
        :rtype: str
        """
        return self._share_id

    @share_id.setter
    def share_id(self, share_id):
        """Sets the share_id of this DeleteHpcCacheTaskRequest.

        文件系统ID

        :param share_id: The share_id of this DeleteHpcCacheTaskRequest.
        :type share_id: str
        """
        self._share_id = share_id

    @property
    def task_id(self):
        """Gets the task_id of this DeleteHpcCacheTaskRequest.

        任务ID

        :return: The task_id of this DeleteHpcCacheTaskRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this DeleteHpcCacheTaskRequest.

        任务ID

        :param task_id: The task_id of this DeleteHpcCacheTaskRequest.
        :type task_id: str
        """
        self._task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteHpcCacheTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksfsturbo-3.1.146-py2.py3-none-any.whl: huaweicloudsdksfsturbo/v1/model/delete_hpc_cache_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteHpcCacheTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'share_id': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'share_id': 'share_id',
        'task_id': 'task_id'
    }

    def __init__(self, share_id=None, task_id=None):
        r"""DeleteHpcCacheTaskRequest

        The model defined in huaweicloud sdk

        :param share_id: 文件系统ID
        :type share_id: str
        :param task_id: 任务ID
        :type task_id: str
        """
        
        

        self._share_id = None
        self._task_id = None
        self.discriminator = None

        self.share_id = share_id
        self.task_id = task_id

    @property
    def share_id(self):
        r"""Gets the share_id of this DeleteHpcCacheTaskRequest.

        文件系统ID

        :return: The share_id of this DeleteHpcCacheTaskRequest.
        :rtype: str
        """
        return self._share_id

    @share_id.setter
    def share_id(self, share_id):
        r"""Sets the share_id of this DeleteHpcCacheTaskRequest.

        文件系统ID

        :param share_id: The share_id of this DeleteHpcCacheTaskRequest.
        :type share_id: str
        """
        self._share_id = share_id

    @property
    def task_id(self):
        r"""Gets the task_id of this DeleteHpcCacheTaskRequest.

        任务ID

        :return: The task_id of this DeleteHpcCacheTaskRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        r"""Sets the task_id of this DeleteHpcCacheTaskRequest.

        任务ID

        :param task_id: The task_id of this DeleteHpcCacheTaskRequest.
        :type task_id: str
        """
        self._task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteHpcCacheTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
